summaryrefslogtreecommitdiffstats
path: root/tdecore/kextsock.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 13:15:51 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 13:15:51 -0600
commitd1bd46309ad2bee123bdf9081ae5b4e0aa7ccc7e (patch)
treeecd8c94dc36cb35dd4810a2b05d1b78bb969e143 /tdecore/kextsock.h
parent703fb0c89c2eee56a1e613e67a446db9d4287929 (diff)
downloadtdelibs-d1bd46309ad2bee123bdf9081ae5b4e0aa7ccc7e.tar.gz
tdelibs-d1bd46309ad2bee123bdf9081ae5b4e0aa7ccc7e.zip
Rename KServer, KSocket, KIO_EXPORT, KIOInput, KIOJob, KIOConfig, KIOBuffer, and KBuffer to avoid conflicts with KDE4
Diffstat (limited to 'tdecore/kextsock.h')
-rw-r--r--tdecore/kextsock.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/tdecore/kextsock.h b/tdecore/kextsock.h
index 6327d51dc..fad502c04 100644
--- a/tdecore/kextsock.h
+++ b/tdecore/kextsock.h
@@ -92,7 +92,7 @@ class KExtendedSocketPrivate;
* @author Thiago Macieira <thiago.macieira@kdemail.net>
* @short an extended socket
*/
-class TDECORE_EXPORT KExtendedSocket: public KBufferedIO // public TQObject, public QIODevice
+class TDECORE_EXPORT KExtendedSocket: public TDEBufferedIO // public TQObject, public QIODevice
{
Q_OBJECT
@@ -582,7 +582,7 @@ public:
* @li #closed() will only be sent if we are indeed reading from the input
* stream. That is, if this socket is buffering the input. See setBufferSize
*
* Note that, in general, functions inherited/overridden from KBufferedIO will only
* work on buffered sockets, like bytesAvailable and bytesToWrite.
* @return The return values are:
* @li 0: success
@@ -582,7 +582,7 @@ public:
* stream. That is, if this socket is buffering the input. See setBufferSize
*
- * Note that, in general, functions inherited/overridden from KBufferedIO will only
+ * Note that, in general, functions inherited/overridden from TDEBufferedIO will only
* work on buffered sockets, like bytesAvailable and bytesToWrite.
* @return The return values are: